@@ -26,315 +26,7 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Log: codecs.h,v $
- * Revision 1.7  2010/09/19 05:43:39  shorne
- * Added SetSupportedFormats
- *
- * Revision 1.6  2010/06/06 14:53:26  shorne
- * Added AVSync support, Aspect Ratio management, flow Control, Video 90k clock, fixes for wideband codecs and generic audio capabilities
- *
- * Revision 1.5  2010/05/02 22:43:05  shorne
- * Added RTP Information structure to be able to support A/V sync
- *
- * Revision 1.4  2009/07/09 15:11:12  shorne
- * Simplfied and standardised compiler directives
- *
- * Revision 1.3  2008/05/23 11:19:05  willamowius
- * switch BOOL to PBoolean to be able to compile with Ptlib 2.2.x
- *
- * Revision 1.2  2007/10/19 19:53:44  shorne
- * ported latest Video updates in OpenH323 committed after h323plus initial fork thanks
- *  Robert
- *
- * Revision 1.1  2007/08/06 20:50:48  shorne
- * First commit of h323plus
- *
- * Revision 1.81.2.5  2007/07/19 20:10:27  shorne
- * Changed HAS_AEC to H323_AEC
- *
- * Revision 1.81.2.4  2007/02/10 23:56:40  shorne
- * Added comment
- *
- * Revision 1.81.2.3  2007/02/05 05:17:00  shorne
- * Added ability to send general codec options to Video Plugins
- *
- * Revision 1.81.2.2  2007/01/30 14:39:55  shorne
- * Corrections and Improvements patch supplied by Guilhem Tardy
- *
- * Revision 1.81.2.1  2006/12/23 19:08:02  shorne
- * Plugin video codecs & sundry
- *
- * Revision 1.81  2006/08/01 06:17:48  csoutheren
- * Fix bit rate control units
- * Add access function on code for max bit rate
- * Thanks to Paolo Amadini
- *
- * Revision 1.80  2006/05/16 11:28:58  shorne
- * added AEC support and  more call hold support.
- *
- * Revision 1.79  2006/01/26 03:31:08  shorne
- * Add the ability to remove a local input device when placing a call on hold
- *
- * Revision 1.78  2005/11/30 13:05:01  csoutheren
- * Changed tags for Doxygen
- *
- * Revision 1.77  2005/06/07 07:09:13  csoutheren
- * Removed compiler warnings on Windows
- *
- * Revision 1.76  2005/06/07 03:22:22  csoutheren
- * Added patch 1198741 with support for plugin codecs with generic capabilities
- * Added patch 1198754 with support for setting quality level on audio codecs
- * Added patch 1198760 with GSM-AMR codec support
- * Many thanks to Richard van der Hoff for his work
- *
- * Revision 1.75  2005/01/03 06:25:52  csoutheren
- * Added extensive support for disabling code modules at compile time
- *
- * Revision 1.74  2004/07/03 06:48:26  rjongbloed
- * Split video temporal/spatial trade off H.245 packets to separate command and
- *   indication functions and added quality parameter, thanks Guilhem Tardy.
- *
- * Revision 1.73  2004/05/09 10:08:34  csoutheren
- * Changed new DecodeFrame to return bytes decoded rather than samples decoded
- * Added support for new DecodeFrame to plugin manager
- *
- * Revision 1.72  2004/05/02 04:52:23  rjongbloed
- * Fixed problems with G.711 caused by fixing problem with G.723.1-5k3 mode.
- *
- * Revision 1.71  2004/03/24 00:39:12  dereksmithies
- * Changes from Michael Smith for use in reporting frames/second. Many Thanks
- *
- * Revision 1.70  2003/12/14 10:42:29  rjongbloed
- * Changes for compilability without video support.
- *
- * Revision 1.69  2003/11/12 11:14:21  csoutheren
- * Added H323FramedAudioCodec::DecodeSilenceFrame thanks to Henry Harrison of AliceStreet
- *
- * Revision 1.68  2003/07/16 10:43:12  csoutheren
- * Added SwapChannel function to H323Codec to allow media hold channels
- * to work better. Thanks to Federico Pinna
- *
- * Revision 1.67  2003/05/27 09:39:15  dereksmithies
- * Add frames per sec variable to the videocodec class
- *
- * Revision 1.66  2002/12/16 09:11:15  robertj
- * Added new video bit rate control, thanks Walter H. Whitlock
- *
- * Revision 1.65  2002/09/16 01:14:15  robertj
- * Added #define so can select if #pragma interface/implementation is used on
- *   platform basis (eg MacOS) rather than compiler, thanks Robert Monaghan.
- *
- * Revision 1.64  2002/08/05 10:03:47  robertj
- * Cosmetic changes to normalise the usage of pragma interface/implementation.
- *
- * Revision 1.63  2002/01/23 06:13:52  robertj
- * Added filter function hooks to codec raw data channel.
- *
- * Revision 1.62  2002/01/23 01:58:25  robertj
- * Added function to determine if codecs raw data channel is native format.
- *
- * Revision 1.61  2002/01/22 16:17:19  rogerh
- * Back out the DTMF Decoder class. There will soon be a better way
- * to do this.
- *
- * Revision 1.60  2002/01/22 16:09:38  rogerh
- * Back out the DTMF detection from H323FramedAudioCodec::Write().
- * There will shortly be a better place for it.
- *
- * Revision 1.59  2002/01/22 15:21:47  rogerh
- * Add DTMF decoding to PCM audio streams. This has been tested with
- * NetMeeting sending Dial Pad codes, using the G.711 codec.
- * At this time, DTMF codes (fron NetMeeting) are just displayed on the
- * screen and are not passed up to the users application.
- *
- * Revision 1.58  2002/01/13 23:56:01  robertj
- * Added mutex so can change raw data channel while reading/writing from codec.
- *
- * Revision 1.57  2001/12/04 05:13:09  robertj
- * Added videa bandwidth limiting code for H.261, thanks Jose Luis Urien.
- *
- * Revision 1.56  2001/11/16 01:05:21  craigs
- * Changed to allow access to uLaw/ALaw to/from linear functions
- *
- * Revision 1.55  2001/10/23 02:18:06  dereks
- * Initial release of CU30 video codec.
- *
- * Revision 1.54  2001/09/25 03:14:47  dereks
- * Add constant bitrate control for the h261 video codec.
- * Thanks Tiziano Morganti for the code to set bit rate. Good work!
- *
- * Revision 1.53  2001/09/11 01:24:36  robertj
- * Added conditional compilation to remove video and/or audio codecs.
- *
- * Revision 1.52  2001/08/28 09:27:38  robertj
- * Updated documentation to reflect some relationships between functions.
- *
- * Revision 1.51  2001/03/29 23:44:35  robertj
- * Added ability to get current silence detect state and threshold.
- * Changed silence detection to use G.723.1 SID frames as indicator of
- *   silence instead of using the average energy and adaptive threshold.
- * Changed default signal on deadband time to be much shorter.
- *
- * Revision 1.50  2001/02/09 05:16:24  robertj
- * Added #pragma interface for GNU C++.
- *
- * Revision 1.49  2001/01/25 07:27:14  robertj
- * Major changes to add more flexible OpalMediaFormat class to normalise
- *   all information about media types, especially codecs.
- *
- * Revision 1.48  2000/12/19 22:33:44  dereks
- * Adjust so that the video channel is used for reading/writing raw video
- * data, which better modularizes the video codec.
- *
- * Revision 1.47  2000/10/13 01:47:26  dereks
- * Include command option for setting the number of transmitted video
- * frames per second.   use --videotxfps n
- *
- * Revision 1.46  2000/09/08 06:41:37  craigs
- * Added ability to set video device
- * Added ability to select test input frames
- *
- * Revision 1.45  2000/08/31 08:15:32  robertj
- * Added support for dynamic RTP payload types in H.245 OpenLogicalChannel negotiations.
- *
- * Revision 1.44  2000/08/21 04:45:06  dereks
- * Fix dangling pointer that caused segfaults for windows&unix users.
- * Improved the test image which is used when video grabber won't open.
- * Added code to handle setting of video Tx Quality.
- * Added code to set the number of background blocks sent with every frame.
- *
- * Revision 1.43  2000/05/16 02:04:16  craigs
- * Added access functions for silence compression mode
- *
- * Revision 1.42  2000/05/02 04:32:24  robertj
- * Fixed copyright notice comment.
- *
- * Revision 1.41  2000/04/14 20:11:16  robertj
- * Removed redundent member variable from H323FramedAudioCodec.
- *
- * Revision 1.40  2000/03/30 23:10:50  robertj
- * Fixed error in comments regarding GetFramerate() function.
- *
- * Revision 1.39  2000/03/21 03:06:47  robertj
- * Changes to make RTP TX of exact numbers of frames in some codecs.
- *
- * Revision 1.38  2000/02/28 13:00:22  robertj
- * Added some virtual keywords at the request of Yura Ershov
- *
- * Revision 1.37  2000/02/10 03:08:02  craigs
- * Added ability to specify NTSC or PAL video format
- *
- * Revision 1.36  2000/02/04 05:00:08  craigs
- * Changes for video transmission
- *
- * Revision 1.35  2000/01/13 04:03:45  robertj
- * Added video transmission
- *
- * Revision 1.34  1999/12/31 00:05:36  robertj
- * Added Microsoft ACM G.723.1 codec capability.
- *
- * Revision 1.33  1999/12/29 01:19:16  craigs
- * Fixed problem with RTP payload type variable
- *
- * Revision 1.32  1999/12/23 23:02:34  robertj
- * File reorganision for separating RTP from H.323 and creation of LID for VPB support.
- *
- * Revision 1.31  1999/11/29 09:01:46  craigs
- * Added new code for new video code interface
- *
- * Revision 1.30  1999/11/29 04:50:11  robertj
- * Added adaptive threshold calculation to silence detection.
- *
- * Revision 1.29  1999/11/20 00:53:46  robertj
- * Fixed ability to have variable sized frames in single RTP packet under G.723.1
- *
- * Revision 1.28  1999/11/13 14:10:32  robertj
- * Changes to make silence detection selectable.
- *
- * Revision 1.27  1999/11/11 23:28:52  robertj
- * Added first cut silence detection algorithm.
- *
- * Revision 1.26  1999/11/04 00:43:42  robertj
- * Added extra constructors for nonStandard codecs.
- *
- * Revision 1.25  1999/10/14 12:03:08  robertj
- * Fixed comment.
- *
- * Revision 1.24  1999/10/08 09:59:01  robertj
- * Rewrite of capability for sending multiple audio frames
- *
- * Revision 1.23  1999/10/08 04:58:37  robertj
- * Added capability for sending multiple audio frames in single RTP packet
- *
- * Revision 1.22  1999/09/23 07:25:12  robertj
- * Added open audio and video function to connection and started multi-frame codec send functionality.
- *
- * Revision 1.21  1999/09/21 14:51:33  robertj
- * Fixed NonStandardCapabilityInfo class virtual destructor (and name).
- *
- * Revision 1.20  1999/09/21 14:04:41  robertj
- * Added non-standard codec capability classes
- *
- * Revision 1.19  1999/09/21 08:12:49  craigs
- * Added support for video codecs and H261
- *
- * Revision 1.18  1999/09/18 13:27:24  craigs
- * Added ability disable jitter buffer for codecs
- * Added ability to access entire RTP frame from codec Write
- *
- * Revision 1.17  1999/09/08 04:05:48  robertj
- * Added support for video capabilities & codec, still needs the actual codec itself!
- *
- * Revision 1.16  1999/08/31 12:34:18  robertj
- * Added gatekeeper support.
- *
- * Revision 1.15  1999/08/25 03:08:23  robertj
- * Added UserInput capability.
- * Allowed the attachment of a channel on a codec to optionally delete the channel object,
- *
- * Revision 1.14  1999/07/22 14:32:48  robertj
- * Fixed erroneous comments
- *
- * Revision 1.13  1999/07/16 16:05:48  robertj
- * Added "human readable" codec type name display.
- *
- * Revision 1.12  1999/07/15 14:45:35  robertj
- * Added propagation of codec open error to shut down logical channel.
- * Fixed control channel start up bug introduced with tunnelling.
- *
- * Revision 1.11  1999/07/13 09:53:24  robertj
- * Fixed some problems with jitter buffer and added more debugging.
- *
- * Revision 1.10  1999/07/09 06:09:49  robertj
- * Major implementation. An ENORMOUS amount of stuff added everywhere.
- *
- * Revision 1.9  1999/06/24 13:32:45  robertj
- * Fixed ability to change sound device on codec and fixed NM3 G.711 compatibility
- *
- * Revision 1.8  1999/06/22 13:49:40  robertj
- * Added GSM support and further RTP protocol enhancements.
- *
- * Revision 1.7  1999/06/14 15:08:40  robertj
- * Added GSM codec class frame work (still no actual codec).
- *
- * Revision 1.6  1999/06/14 06:39:08  robertj
- * Fixed problem with getting transmit flag to channel from PDU negotiator
- *
- * Revision 1.5  1999/06/14 05:15:55  robertj
- * Changes for using RTP sessions correctly in H323 Logical Channel context
- *
- * Revision 1.4  1999/06/13 12:41:14  robertj
- * Implement logical channel transmitter.
- * Fixed H245 connect on receiving call.
- *
- * Revision 1.3  1999/06/09 05:26:19  robertj
- * Major restructuring of classes.
- *
- * Revision 1.2  1999/06/06 06:06:36  robertj
- * Changes for new ASN compiler and v2 protocol ASN files.
- *
- * Revision 1.1  1999/01/16 01:31:01  robertj
- * Initial revision
+ * $ Id $
  *
  */
 
@@ -384,16 +76,18 @@ class H323Codec : public PObject
 	struct H323_RTPInformation
 	{
 		int                   m_sessionID;
+        unsigned              m_timeStamp;
+        unsigned              m_clockRate;
         int                   m_frameLost;
-        PTime                 m_sendTime;
-        PTime                 m_recvTime;
+        PInt64                m_sendTime;
+        PInt64                m_recvTime;
 		const RTP_DataFrame * m_frame;
 	};
 
     struct AVSync
     {
-        DWORD m_rtpTimeStamp;
-        PTime m_realTimeStamp;
+        DWORD  m_rtpTimeStamp;
+        PInt64 m_realTimeStamp;
     };
 
     H323Codec(
@@ -455,6 +149,8 @@ class H323Codec : public PObject
 
        This function is called every GetFrameRate() timestamp units, so MUST
        take less than that amount of time to complete!
+
+       This may call write Internal
      */
     virtual PBoolean Write(
       const BYTE * buffer,          ///< Buffer of encoded data
@@ -463,6 +159,25 @@ class H323Codec : public PObject
       unsigned & written            ///< Number of bytes used from data buffer
     ) = 0;
 
+    /**Decode the data and output it to appropriate device.
+       This will decode a single frame of received data. The exact size and
+       description of the data required in the buffer is codec dependent but
+       should be at least than OpalMediaFormat::GetFrameSize() in length.
+
+       It is expected this function anunciates the data. That is, for example
+       with audio data, the sound is output on a speaker.
+
+       This function is called every GetFrameRate() timestamp units, so MUST
+       take less than that amount of time to complete!
+     */
+    virtual PBoolean WriteInternal(
+      const BYTE * /*buffer*/,              ///< Buffer of encoded data
+      unsigned /*length*/,                  ///< Length of encoded data buffer
+      const RTP_DataFrame & /*frame*/,      ///< Entire RTP frame
+      unsigned & /*written*/,               ///< Number of bytes used from data buffer
+      H323_RTPInformation &  /*rtp*/        ///< RTP Information
+    ) { return false; }
+
     /**Get the frame rate in RTP timestamp units.
       */
     virtual unsigned GetFrameRate() const;
@@ -550,6 +265,14 @@ class H323Codec : public PObject
 	  void * mark
     );
 
+    /**Write from the raw data channel.
+      */
+    PBoolean WriteInternal(
+      void * data,
+      PINDEX length,
+	  void * mark
+    );
+
     /**Attach the logical channel, for use by the codec.
        The channel provided is not deleted on destruction, it is just used.
 
@@ -603,12 +326,16 @@ class H323Codec : public PObject
    /**On Receive sender report.
         Use this for AV Synchronisation
     */
-    virtual PBoolean OnRxSenderReport(DWORD rtpTimeStamp, const PTime & realTimeStamp);
+    virtual PBoolean OnRxSenderReport(DWORD rtpTimeStamp, const PInt64 & realTimeStamp);
 
    /**Calculate the remote send time
     */
     virtual PTime CalculateRTPSendTime(DWORD timeStamp, unsigned rate) const;
 
+   /**Calculate the remote send time
+    */
+    void CalculateRTPSendTime(DWORD timeStamp, unsigned rate, PInt64 & sendTime) const;
+
   protected:
     Direction direction;
     OpalMediaFormat mediaFormat;
@@ -624,7 +351,7 @@ class H323Codec : public PObject
 	H323_RTPInformation  rtpInformation;
     AVSync  rtpSync;
 
-    PLIST(FilterList, PNotifier);
+    H323LIST(FilterList, PNotifier);
     FilterList filters;
 };
 
@@ -637,7 +364,7 @@ class H323Codec : public PObject
    An application may create a descendent off this class and override
    functions as required for descibing a specific codec.
  */
-class PAec;
+class H323Aec;
 class H323AudioCodec : public H323Codec
 {
   PCLASSINFO(H323AudioCodec, H323Codec);
@@ -754,7 +481,7 @@ class H323AudioCodec : public H323Codec
 	/** Attach Acoustic Echo Cancellation.
 	*/
 	virtual void AttachAEC(
-       PAec * /*_ARC*/   ///* Acoustic Echo Cancellation Instance
+       H323Aec * /*_ARC*/   ///* Acoustic Echo Cancellation Instance
     ) {};
 #endif
 
@@ -786,7 +513,7 @@ class H323AudioCodec : public H323Codec
    An application may create a descendent off this class and override
    functions as required for descibing a specific codec.
  */
-class PAec;
+class H323Aec;
 class H323FramedAudioCodec : public H323AudioCodec
 {
   PCLASSINFO(H323FramedAudioCodec, H323AudioCodec);
@@ -889,15 +616,17 @@ class H323FramedAudioCodec : public H323AudioCodec
     { memset(buffer, 0, length); }
 
 #ifdef H323_AEC	
-	/** Attach Acoustic Echo Cancellation.
-	*/
-	virtual void AttachAEC(
-       PAec * _ARC   ///* Acoustic Echo Cancellation Instance
+    /** Attach Acoustic Echo Cancellation.
+    */
+    virtual void AttachAEC(
+       H323Aec * _ARC   ///* Acoustic Echo Cancellation Instance
     );
 #endif
 
   protected:
-	PAec * aec;     // Acoustic Echo Canceller
+#ifdef H323_AEC	
+    H323Aec * aec;     // Acoustic Echo Canceller
+#endif
     PShortArray sampleBuffer;
     unsigned    bytesPerFrame;
 };
@@ -1166,6 +895,19 @@ class H323VideoCodec : public H323Codec
       unsigned ms ///< new time between frames
     );
 
+    /**
+       Set whether is preference frame rate over video quality.
+       This will emphasize speed over quality for a given bitrate.
+       With Speed the video frame size may be smaller with a higher frame rate (>20)
+       With Quality the video frame size is larger with a lower frame rate (>10)
+    */
+    virtual void SetEmphasisSpeed(bool speed);
+
+    /**
+       Set the maximum allowable MTU Size of the RTP Frame
+    */
+    virtual void SetMaxPayloadSize(int maxSize);
+
     /**
        Set a miscellaneous option setting in the video codec.
        This message is used for Video Plugin Codecs.
@@ -1188,8 +930,9 @@ class H323VideoCodec : public H323Codec
 
    /**
       Set the supported Formats the codec is to support
+      Return whether codec supports setting Supported Formats.
     */
-    virtual void SetSupportedFormats(std::list<PVideoFrameInfo> & info);
+    virtual PBoolean SetSupportedFormats(std::list<PVideoFrameInfo> & info);
 
   protected:
 
