@@ -33,7 +33,7 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Id: gnugknat.h,v 1.13 2011/05/09 07:14:03 shorne Exp $
+ * $Id: gnugknat.h,v 1.15 2012/12/10 17:56:08 shorne Exp $
  *
  *
  */
@@ -65,6 +65,7 @@ class GNUGKTransport  : public H323TransportTCP
      */
     GNUGKTransport(
       H323EndPoint & endpoint,        /// H323 End Point object
+      PIPSocket::Address binding,     /// Bind Interface
 	  GNUGK_Feature * feat,			  /// Feature
 	  PString & gkid                  /// Gatekeeper ID
     );
@@ -229,11 +230,15 @@ public:
 
    PBoolean OpenSocket(PUDPSocket & socket, PortInfo & portInfo, const PIPSocket::Address & binding) const;
 
-
+#if PTLIB_VER > 2120
+   static PString GetNatMethodName() { return "GnuGk"; }
+   virtual PString GetName() const
+            { return GetNatMethodName(); }
+#else
    static PStringList GetNatMethodName() {  return PStringArray("GnuGk"); };
    virtual PString GetName() const
             { return GetNatMethodName()[0]; }
-
+#endif
 
    // All these are virtual and never used. 
     virtual bool GetServerAddress(
@@ -266,6 +271,8 @@ public:
     virtual bool CreateSocket(BYTE component,PUDPSocket * & socket,
             const PIPSocket::Address & binding = PIPSocket::GetDefaultIpAny(),WORD localPort = 0)  { return false; }
     virtual void SetCredentials(const PString &, const PString &, const PString &) {}
+protected:
+    virtual NatTypes InternalGetNatType(bool, const PTimeInterval &) { return UnknownNat; }
 #endif
 
 
