@@ -34,6 +34,9 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: h323filetransfer.h,v $
+ * Revision 1.4  2011/10/18 13:32:30  shorne
+ * Rearranged Default Session ids so FECC is Session 3 for better interoperability.
+ *
  * Revision 1.3  2009/02/21 14:06:02  shorne
  * Major FileTransfer code review and improvement
  *
@@ -258,6 +261,14 @@ class H323FileTransferCapability : public H323DataCapability
        using the enum values of the protocol ASN H245_AudioCapability class.
      */
 	virtual unsigned GetSubType() const;
+
+    /**Get the default RTP session.
+       This function gets the default RTP session ID for the capability
+       type. 
+       The default behaviour returns zero, indicating it is not an RTP
+       based capability.
+      */
+    virtual unsigned GetDefaultSessionID() const;
   //@}
     
   /**@name Protocol manipulation */
