@@ -24,6 +24,9 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: peclient.h,v $
+ * Revision 1.3  2011/05/09 07:35:47  shorne
+ * updates for changes in PTLIB v2.11. The replacement of PDICTIONARY with H323Dictionary. Updates for the changes in the PNatMethod Class. Alteration in PFactory::Create, Remove redundent code and change change logging
+ *
  * Revision 1.2  2008/05/23 11:19:56  willamowius
  * switch BOOL to PBoolean to be able to compile with Ptlib 2.2.x
  *
@@ -620,7 +623,7 @@ class H323PeerElement : public H323_AnnexG
     PMutex remotePeerListMutex;
     PSafeSortedList<H323PeerElementServiceRelationship> remoteServiceRelationships;
     PStringToString remotePeerAddrToServiceID;
-    PDICTIONARY(StringToOrdinalKey, PString, POrdinalKey);
+    H323DICTIONARY(StringToOrdinalKey, PString, POrdinalKey);
     StringToOrdinalKey remotePeerAddrToOrdinalKey;
 
     PSafeSortedList<H323PeerElementDescriptor> descriptors;
